Dataset adapters
================

Adapters can be used when a collection is derived from another one by
subsampling document and/or queries.

.. currentmodule:: xpmir.datasets.adapters

.. autoxpmconfig:: RandomFold
.. autoxpmconfig:: RetrieverBasedCollection

.. autoxpmconfig:: AdhocTopicFold
.. autoxpmconfig:: AdhocAssessmentFold
.. autoxpmconfig:: AdhocDocumentSubset
.. autoxpmconfig:: MemoryTopicStore
